==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkGenericInterpolatedVelocityField.java <==
// java wrapper for vtkGenericInterpolatedVelocityField object
//

package vtk;
import vtk.*;

public class vtkGenericInterpolatedVelocityField extends vtkFunctionSet
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void AddDataSet_2(vtkGenericDataSet id0);
  public void AddDataSet(vtkGenericDataSet id0)
    { AddDataSet_2(id0); }

  private native void ClearLastCell_3();
  public void ClearLastCell()
    { ClearLastCell_3(); }

  private native long GetLastCell_4();
  public vtkGenericAdaptorCell GetLastCell() {
    long temp = GetLastCell_4();

    if (temp == 0) return null;
    return (vtkGenericAdaptorCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetLastLocalCoordinates_5(double id0[]);
  public int GetLastLocalCoordinates(double id0[])
    { return GetLastLocalCoordinates_5(id0); }

  private native int GetCaching_6();
  public int GetCaching()
    { return GetCaching_6(); }

  private native void SetCaching_7(int id0);
  public void SetCaching(int id0)
    { SetCaching_7(id0); }

  private native void CachingOn_8();
  public void CachingOn()
    { CachingOn_8(); }

  private native void CachingOff_9();
  public void CachingOff()
    { CachingOff_9(); }

  private native int GetCacheHit_10();
  public int GetCacheHit()
    { return GetCacheHit_10(); }

  private native int GetCacheMiss_11();
  public int GetCacheMiss()
    { return GetCacheMiss_11(); }

  private native String GetVectorsSelection_12();
  public String GetVectorsSelection()
    { return GetVectorsSelection_12(); }

  private native void SelectVectors_13(String id0);
  public void SelectVectors(String id0)
    { SelectVectors_13(id0); }

  private native long GetLastDataSet_14();
  public vtkGenericDataSet GetLastDataSet() {
    long temp = GetLastDataSet_14();

    if (temp == 0) return null;
    return (vtkGenericDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void CopyParameters_15(vtkGenericInterpolatedVelocityField id0);
  public void CopyParameters(vtkGenericInterpolatedVelocityField id0)
    { CopyParameters_15(id0); }

  public vtkGenericInterpolatedVelocityField() { super(); }

  public vtkGenericInterpolatedVelocityField(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv6h.pkg.tar.xz: vtk/vtkGenericInterpolatedVelocityField.java <==
// java wrapper for vtkGenericInterpolatedVelocityField object
//

package vtk;
import vtk.*;

public class vtkGenericInterpolatedVelocityField extends vtkFunctionSet
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void AddDataSet_2(vtkGenericDataSet id0);
  public void AddDataSet(vtkGenericDataSet id0)
    { AddDataSet_2(id0); }

  private native void ClearLastCell_3();
  public void ClearLastCell()
    { ClearLastCell_3(); }

  private native long GetLastCell_4();
  public vtkGenericAdaptorCell GetLastCell() {
    long temp = GetLastCell_4();

    if (temp == 0) return null;
    return (vtkGenericAdaptorCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetLastLocalCoordinates_5(double id0[]);
  public int GetLastLocalCoordinates(double id0[])
    { return GetLastLocalCoordinates_5(id0); }

  private native int GetCaching_6();
  public int GetCaching()
    { return GetCaching_6(); }

  private native void SetCaching_7(int id0);
  public void SetCaching(int id0)
    { SetCaching_7(id0); }

  private native void CachingOn_8();
  public void CachingOn()
    { CachingOn_8(); }

  private native void CachingOff_9();
  public void CachingOff()
    { CachingOff_9(); }

  private native int GetCacheHit_10();
  public int GetCacheHit()
    { return GetCacheHit_10(); }

  private native int GetCacheMiss_11();
  public int GetCacheMiss()
    { return GetCacheMiss_11(); }

  private native String GetVectorsSelection_12();
  public String GetVectorsSelection()
    { return GetVectorsSelection_12(); }

  private native void SelectVectors_13(String id0);
  public void SelectVectors(String id0)
    { SelectVectors_13(id0); }

  private native long GetLastDataSet_14();
  public vtkGenericDataSet GetLastDataSet() {
    long temp = GetLastDataSet_14();

    if (temp == 0) return null;
    return (vtkGenericDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CopyParameters_15(vtkGenericInterpolatedVelocityField id0);
  public void CopyParameters(vtkGenericInterpolatedVelocityField id0)
    { CopyParameters_15(id0); }

  public vtkGenericInterpolatedVelocityField() { super(); }

  public vtkGenericInterpolatedVelocityField(long id) { super(id); }
  public native long   VTKInit();

}
